@@ -10,10 +10,10 @@ import subprocess
 from pathlib import Path
 from typing import Any, Dict, List, Tuple
 
-from blight.enums import CompilerStage, Lang, OptLevel, Std
+from blight.enums import CodeModel, CompilerStage, Lang, OptLevel, Std
 from blight.exceptions import BlightError, BuildError
 from blight.protocols import ArgsProtocol, IndexedUndefinesProtocol, LangProtocol
-from blight.util import insert_items_at_idx, load_actions, rindex_prefix
+from blight.util import insert_items_at_idx, load_actions, rindex_prefix, ritem_prefix
 
 logger = logging.getLogger(__name__)
 
@@ -23,9 +23,10 @@ BLIGHT_TOOL_MAP = {
     "blight-cpp": "CPP",
     "blight-ld": "LD",
     "blight-as": "AS",
+    "blight-ar": "AR",
 }
 
-TOOL_ENV_MAP = {"CC": "cc", "CXX": "c++", "CPP": "cpp", "LD": "ld", "AS": "as"}
+TOOL_ENV_MAP = {"CC": "cc", "CXX": "c++", "CPP": "cpp", "LD": "ld", "AS": "as", "AR": "ar"}
 
 TOOL_ENV_WRAPPER_MAP = {
     "CC": "BLIGHT_WRAPPED_CC",
@@ -33,6 +34,7 @@ TOOL_ENV_WRAPPER_MAP = {
     "CPP": "BLIGHT_WRAPPED_CPP",
     "LD": "BLIGHT_WRAPPED_LD",
     "AS": "BLIGHT_WRAPPED_AS",
+    "AR": "BLIGHT_WRAPPED_AR",
 }
 
 RESPONSE_FILE_RECURSION_LIMIT = 64
@@ -536,10 +538,42 @@ class DefinesMixin:
         return defines
 
 
+class CodeModelMixin:
+    """
+    A mixin for tools that support the `-mcmodel=MODEL` syntax for declaring their
+    code model.
+    """
+
+    @property
+    def code_model(self: ArgsProtocol):
+        """
+        Returns:
+            A `blight.enums.CodeModel` value representing the tool's code model
+        """
+        code_model_map = {
+            "-mcmodel=small": CodeModel.Small,
+            "-mcmodel=medlow": CodeModel.Small,
+            "-mcmodel=medium": CodeModel.Medium,
+            "-mcmodel=medany": CodeModel.Medium,
+            "-mcmodel=large": CodeModel.Large,
+            "-mcmodel=kernel": CodeModel.Kernel,
+        }
+
+        # NOTE(ww): Both Clang and GCC seem to default to the "small" code model
+        # when none is specified, at least on x86-64. But this might not be consistent
+        # across architectures, so maybe we should return `CodeModel.Unknown` here
+        # instead.
+        code_model = ritem_prefix(self.args, "-mcmodel=")
+        if code_model is None:
+            return CodeModel.Small
+
+        return code_model_map.get(code_model, CodeModel.Unknown)
+
+
 # NOTE(ww): The funny mixin order here (`ResponseFileMixin` before `Tool`) and elsewhere
 # is because Python defines its class hierarchy from right to left. `ResponseFileMixin`
 # therefore needs to come first in order to properly override `args`.
-class CompilerTool(ResponseFileMixin, Tool, StdMixin, OptMixin, DefinesMixin):
+class CompilerTool(ResponseFileMixin, Tool, StdMixin, OptMixin, DefinesMixin, CodeModelMixin):
     """
     Represents a generic (C or C++) compiler frontend.
 
@@ -696,3 +730,12 @@ class AS(ResponseFileMixin, Tool):
 
     def __repr__(self) -> str:
         return f"<AS {self.wrapped_tool()}>"
+
+
+class AR(Tool):
+    """
+    Represents the archiver.
+    """
+
+    def __repr__(self) -> str:
+        return f"<AR {self.wrapped_tool()}>"
